@@ -411,7 +411,7 @@ typedef void
     int                                 cls,
     void *                              user_arg);
 
-/** 
+/**
  *  create a passive data object
  *
  *  this function is called to tell the user to create a passively 
@@ -431,7 +431,7 @@ typedef void
     const char *                            pathname,
     void *                                  user_arg);
 
-/** 
+/**
  *  create an active data object
  *
  *  this function is called to tell the user to create an actively
@@ -563,6 +563,11 @@ globus_gridftp_server_control_attr_set_epsv_ip(
     globus_gridftp_server_control_attr_t    in_attr,
     globus_bool_t                           epsv_ip);
 
+globus_result_t
+globus_gridftp_server_control_attr_set_ipv6(
+    globus_gridftp_server_control_attr_t    in_attr,
+    globus_bool_t                           ipv6);
+
 /*
  *  if module name is NULL then it is the default handler
  */
